##  Step 2. Define the Transformations necessary to implement a Project
After sharing the first version of your Project Roadmap with your stakeholders, it’s time to start planning how to achieve those projects/initiatives.
This is where the concept of Transformations comes into play. Transformations allow you to outline the changes that are needed to achieve the initiative.
To define Transformations in your project, on a high level, you do the following:
  1. Consult with key stakeholders to identify and define changes to the IT infrastructure, applications, and processes.
  2. Add Transformations in the Project Fact Sheets, either by using SAP-LeanIX-provided Transformation templates or custom Transformations. Pre-defined Transformation templates automatically generate implied Impacts by capturing changes at the attribute and relation levels of Fact Sheets without implementing the changes in real-time. To learn more about Transformations, see [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.").
  3. Modify Impacts or add Custom Impacts if needed to define your Transformations further. To learn more about Impacts, see [Impacts](https://help.sap.com/docs/leanix/ea/impacts?locale=en-US&state=PRODUCTION&version=CLOUD "Impacts detail the changes at attribute and relation levels. Learn how to manage these Impacts in SAP LeanIX Architecture and Road Map Planning.").


With these steps, you have successfully defined the Transformations needed to implement a project. In the below example, a Transformation item is introducing a new application - “SAP B1 - Finance”. The implied impacts reveal that it is replacing three applications by setting their lifecycle to End of Life.
![Defining Transformation to introduce new Application](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749d3ff7a441014b004ae7535d1b50b_LowRes.png)
Defining Transformation to introduce new Application
